@@ -2,8 +2,8 @@
 ## Helpers to access/process the table names and columns
 .getTableColMapping <- function(x){
   conn <- AnnotationDbi:::dbConn(x)
-  tables <- DBI:::dbListTables(conn)
-  tCols <- sapply(tables, DBI:::dbListFields, conn=conn)
+  tables <- DBI::dbListTables(conn)
+  tCols <- sapply(tables, DBI::dbListFields, conn=conn)
   ## right up front we are getting rid of metadata and chrominfo tables...
   tCols[names(tCols)!="metadata" & names(tCols)!="chrominfo"]
 }
@@ -185,6 +185,8 @@
 .select <- function(x, keys, columns, keytype){
   if(missing(keys)){stop("'keys' must be a character vector")}
   if(missing(columns)){stop("'columns' must be a character vector")}
+  ## Some argument checking
+  AnnotationDbi:::.testSelectArgs(x, keys=keys, cols=columns, keytype=keytype)
   ## 1st we check the keytype to see if it is valid:
   if(is.na(keys(x, keytype)[1]) & length(keys(x, keytype))==1){ 
     stop(paste("There do not appear to be any keys",
@@ -244,8 +246,8 @@
   res <- AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x), sql)
 
   if(length(keys) > 1000){ ##Then drop the extras now(in event there are some)
-      ktColId <- GenomicFeatures:::.reverseColAbbreviations(x,keytype)
-      res <-  res[res[[ktColId]] %in% keys,]
+      ktColId <- .reverseColAbbreviations(x, keytype)
+      res <-  res[res[[ktColId]] %in% keys,,drop=FALSE]
   }
   
   
@@ -322,35 +324,34 @@ setMethod("columns", "TranscriptDb",
 ## method for keys()
 ## PHEW, There are a lot of types.  But names are not always available so...
 .keys <- function(x, keytype){
-    switch(EXPR = keytype,
-           "GENEID" = AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
-             "SELECT DISTINCT gene_id FROM gene", 1L),
-           "TXID" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
-             "SELECT DISTINCT _tx_id FROM transcript", 1L),
-           "TXNAME" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
-             "SELECT DISTINCT tx_name FROM transcript", 1L),
-           "EXONID" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
-             "SELECT DISTINCT _exon_id FROM exon", 1L),
-           "EXONNAME" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
-             "SELECT DISTINCT exon_name FROM exon", 1L),
-           "CDSID" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
-             "SELECT DISTINCT _cds_id FROM cds", 1L),                  
-           "CDSNAME" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
-             "SELECT DISTINCT cds_name FROM cds", 1L),                  
-           stop(paste(keytype, "is not a supported keytype.",
-                      " Please use the keytypes",
-                      "method to identify viable keytypes")))
+    AnnotationDbi:::.testForValidKeytype(x, keytype)
+    res <- switch(EXPR = keytype,
+             "GENEID" = AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
+               "SELECT DISTINCT gene_id FROM gene", 1L),
+             "TXID" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
+               "SELECT DISTINCT _tx_id FROM transcript", 1L),
+             "TXNAME" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
+               "SELECT DISTINCT tx_name FROM transcript", 1L),
+             "EXONID" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
+               "SELECT DISTINCT _exon_id FROM exon", 1L),
+             "EXONNAME" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
+               "SELECT DISTINCT exon_name FROM exon", 1L),
+             "CDSID" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
+               "SELECT DISTINCT _cds_id FROM cds", 1L),                  
+             "CDSNAME" =  AnnotationDbi:::dbQuery(AnnotationDbi:::dbConn(x),
+               "SELECT DISTINCT cds_name FROM cds", 1L),                  
+                  stop(paste(keytype, "is not a supported keytype.",
+                             " Please use the keytypes",
+                             "method to identify viable keytypes")))
+    as.character(res)
 }
 
-tmpFun <-           function(x, keytype, ...){
-              if (missing(keytype)) keytype <- "GENEID"
-              AnnotationDbi:::smartKeys(x=x, keytype=keytype, ...,
-                                        FUN=GenomicFeatures:::.keys)
-          }
+.keysDispatch <- function(x, keytype, ...){
+    if (missing(keytype)) keytype <- "GENEID"
+    AnnotationDbi:::smartKeys(x=x, keytype=keytype, ..., FUN=.keys)
+}
 ## Get the list of possible keys, for a given keytype
-setMethod("keys", "TranscriptDb",tmpFun
-
-)
+setMethod("keys", "TranscriptDb",.keysDispatch)
 
 
 ## Examples to test:
@@ -603,3 +604,13 @@ setMethod("keytypes", "TranscriptDb",
 
 ##
 ## So I think I have this fixed now.  But I still need to add unit tests.
+
+
+
+
+
+###################3##########################################################
+## New bug.  Can reproduce it like this:
+## FIXED
+## library(TxDb.Hsapiens.UCSC.hg19.knownGene); x <- TxDb.Hsapiens.UCSC.hg19.knownGene; geneGR <- exonsBy(x, "gene"); keys <- names(geneGR); kt = "GENEID"; cols = "GENEID"; debug(GenomicFeatures:::.select)
+## GenomicFeatures:::.select(x, keys, columns=cols, keytype=kt)
